A summary of the notebooks included here:

notebook name              |  complexity | description
---------------------------|-------------|--------------------
usage_guide                | beginner    | Detailed documentation & examples on how to use the pyobis package.
occurrences_ocean_sunfish  | beginner    | Basic exploration of data for sunfish species.
depth_time_series.ipynb    | beginner    | A time-series analysis of species depth.
migration_patterns.ipynb   | intermediate| A geo-spatial analysis of sunfish and dolphin species.
contributions_quantifications.ipynb| beginner | A spatio-temporal analysis of contributions made by dataset owners from a specific region (space and time) of interest.
MeasurementOrFact_Analysis.ipynb | beginner | A spatio-temporal analysis of MoF records based on population density, cover and relief features.
Biodiversity Mapping | intermediate | An geospatial analysis of order Scleratinia.
